@@ -55,7 +55,9 @@ class AlbArnTarget(
         :param port: The port on which the target is listening.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AlbArnTarget.__init__)
+            def stub(alb_arn: builtins.str, port: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument alb_arn", value=alb_arn, expected_type=type_hints["alb_arn"])
             check_type(argname="argument port", value=port, expected_type=type_hints["port"])
         jsii.create(self.__class__, self, [alb_arn, port])
@@ -73,7 +75,11 @@ class AlbArnTarget(
         :param target_group: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AlbArnTarget.attach_to_network_target_group)
+            def stub(
+                target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
@@ -134,7 +140,12 @@ class AlbTarget(
         :param port: The port on which the target is listening.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AlbTarget.__init__)
+            def stub(
+                alb: aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer,
+                port: jsii.Number,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument alb", value=alb, expected_type=type_hints["alb"])
             check_type(argname="argument port", value=port, expected_type=type_hints["port"])
         jsii.create(self.__class__, self, [alb, port])
@@ -172,7 +183,12 @@ class InstanceIdTarget(
         :param port: Override the default port for the target group.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(InstanceIdTarget.__init__)
+            def stub(
+                instance_id: builtins.str,
+                port: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
             check_type(argname="argument port", value=port, expected_type=type_hints["port"])
         jsii.create(self.__class__, self, [instance_id, port])
@@ -190,7 +206,11 @@ class InstanceIdTarget(
         :param target_group: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(InstanceIdTarget.attach_to_application_target_group)
+            def stub(
+                target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
 
@@ -207,7 +227,11 @@ class InstanceIdTarget(
         :param target_group: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(InstanceIdTarget.attach_to_network_target_group)
+            def stub(
+                target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
@@ -243,7 +267,12 @@ class InstanceTarget(
         :param port: Override the default port for the target group.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(InstanceTarget.__init__)
+            def stub(
+                instance: aws_cdk.aws_ec2.Instance,
+                port: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument instance", value=instance, expected_type=type_hints["instance"])
             check_type(argname="argument port", value=port, expected_type=type_hints["port"])
         jsii.create(self.__class__, self, [instance, port])
@@ -303,7 +332,13 @@ class IpTarget(
         :param availability_zone: Availability zone to send traffic from.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IpTarget.__init__)
+            def stub(
+                ip_address: builtins.str,
+                port: typing.Optional[jsii.Number] = None,
+                availability_zone: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument ip_address", value=ip_address, expected_type=type_hints["ip_address"])
             check_type(argname="argument port", value=port, expected_type=type_hints["port"])
             check_type(argname="argument availability_zone", value=availability_zone, expected_type=type_hints["availability_zone"])
@@ -322,7 +357,11 @@ class IpTarget(
         :param target_group: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IpTarget.attach_to_application_target_group)
+            def stub(
+                target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
 
@@ -339,7 +378,11 @@ class IpTarget(
         :param target_group: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IpTarget.attach_to_network_target_group)
+            def stub(
+                target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
@@ -379,7 +422,9 @@ class LambdaTarget(
         :param fn: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaTarget.__init__)
+            def stub(fn: aws_cdk.aws_lambda.IFunction) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
         jsii.create(self.__class__, self, [fn])
 
@@ -396,7 +441,11 @@ class LambdaTarget(
         :param target_group: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaTarget.attach_to_application_target_group)
+            def stub(
+                target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
 
@@ -413,7 +462,11 @@ class LambdaTarget(
         :param target_group: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaTarget.attach_to_network_target_group)
+            def stub(
+                target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument target_group", value=target_group, expected_type=type_hints["target_group"])
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
